Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(109)

Unified Diff: third_party/WebKit/Source/bindings/core/v8/ScriptPromiseResolver.cpp

Issue 1696553005: Add ScriptPromiseResolver::detach (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/bindings/core/v8/ScriptPromiseResolver.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/bindings/core/v8/ScriptPromiseResolver.cpp
diff --git a/third_party/WebKit/Source/bindings/core/v8/ScriptPromiseResolver.cpp b/third_party/WebKit/Source/bindings/core/v8/ScriptPromiseResolver.cpp
index 5cdb01e6fa37442285ca6a62247414a36eb7f629..bc0ba8d0f7613a45b14907867731ce8af4efae42 100644
--- a/third_party/WebKit/Source/bindings/core/v8/ScriptPromiseResolver.cpp
+++ b/third_party/WebKit/Source/bindings/core/v8/ScriptPromiseResolver.cpp
@@ -17,7 +17,7 @@ ScriptPromiseResolver::ScriptPromiseResolver(ScriptState* scriptState)
#endif
{
if (executionContext()->activeDOMObjectsAreStopped()) {
- m_state = ResolvedOrRejected;
+ m_state = Detached;
m_resolver.clear();
}
}
@@ -33,10 +33,15 @@ void ScriptPromiseResolver::resume()
m_timer.startOneShot(0, BLINK_FROM_HERE);
}
-void ScriptPromiseResolver::stop()
+void ScriptPromiseResolver::detach()
{
+ if (m_state == Detached)
+ return;
m_timer.stop();
- clear();
+ m_state = Detached;
+ m_resolver.clear();
+ m_value.clear();
+ m_keepAlive.clear();
}
void ScriptPromiseResolver::keepAliveWhilePending()
@@ -44,11 +49,11 @@ void ScriptPromiseResolver::keepAliveWhilePending()
// keepAliveWhilePending() will be called twice if the resolver
// is created in a suspended execution context and the resolver
// is then resolved/rejected while in that suspended state.
- if (m_state == ResolvedOrRejected || m_keepAlive)
+ if (m_state == Detached || m_keepAlive)
return;
// Keep |this| around while the promise is Pending;
// see clear() for the dual operation.
m_keepAlive = this;
}
@@ -56,7 +61,7 @@ void ScriptPromiseResolver::onTimerFired(Timer<ScriptPromiseResolver>*)
{
ASSERT(m_state == Resolving || m_state == Rejecting);
if (!scriptState()->contextIsValid()) {
- clear();
+ detach();
return;
}
@@ -76,17 +81,7 @@ void ScriptPromiseResolver::resolveOrRejectImmediately()
m_resolver.reject(m_value.newLocal(m_scriptState->isolate()));
}
}
- clear();
-}
-
-void ScriptPromiseResolver::clear()
-{
- if (m_state == ResolvedOrRejected)
- return;
- m_state = ResolvedOrRejected;
- m_resolver.clear();
- m_value.clear();
- m_keepAlive.clear();
+ detach();
}
DEFINE_TRACE(ScriptPromiseResolver)
« no previous file with comments | « third_party/WebKit/Source/bindings/core/v8/ScriptPromiseResolver.h ('k') | no next file » | no next file with comments »
@@ -44,11 +49,11 @@ void ScriptPromiseResolver::keepAliveWhilePending()
return;
// Keep |this| around while the promise is Pending;
- // see clear() for the dual operation.
+ // see detach() for the dual operation.
m_keepAlive = this;
}

Powered by Google App Engine
This is Rietveld 408576698